<?php
/**
 * BuddyBoss compatibility for Media.
 *
 * @package    Facebook_Like_Activity_Stream
 * @copyright  Copyright (c) 2020, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 * @since      1.0.0
 */

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Adds compatibility with BuddyBoss media on profile stream.
 */
class BPFBL_BB_Media_Compat_Profile {

	/**
	 * Singleton instance.
	 *
	 * @var BPFBL_BB_Media_Compat_Profile
	 */
	private static $instance = null;

	/**
	 * Get singleton instance.
	 *
	 * @return BPFBL_BB_Media_Compat_Profile
	 */
	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}
		self::$instance->setup();

		return self::$instance;
	}

	/**
	 * Setup hooks.
	 */
	private function setup() {
		add_action( 'bp_before_activity_activity_content', array( $this, 'attach_filter' ) );
		add_action( 'bp_after_activity_activity_content', array( $this, 'detach_filter' ) );
	}

	/**
	 * Set activity user id as media user id.
	 *
	 * @param array $args args.
	 *
	 * @return array
	 */
	public function set_media_user_id( $args ) {
		$args['user_id'] = bp_get_activity_user_id();

		return $args;
	}
	/**
	 * Attach filter to set user id.
	 */
	public function attach_filter() {
		add_filter( 'bp_after_has_media_parse_args', array( $this, 'set_media_user_id' ) );
	}

	/**
	 * Attach filter to set user id.
	 */
	public function detach_filter() {
		remove_filter( 'bp_after_has_media_parse_args', array( $this, 'set_media_user_id' ) );
	}
}

// initialize.
BPFBL_BB_Media_Compat_Profile::get_instance();
